# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class WorkspaceClient:
    def __init__(self, transport):
        self.transport = transport

    def DescribeProject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.workspace.Workspace/DescribeProject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.workspace.DescribeProjectOutput"),
            **kwargs,
        )

    def ListProjects(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.workspace.Workspace/ListProjects",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.workspace.ListProjectsOutput"),
            **kwargs,
        )

    def CreateProject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.workspace.Workspace/CreateProject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.workspace.CreateProjectOutput"),
            **kwargs,
        )

    def UpdateProject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.workspace.Workspace/UpdateProject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.workspace.UpdateProjectOutput"),
            **kwargs,
        )

    def DeleteProject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.workspace.Workspace/DeleteProject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.workspace.DeleteProjectOutput"),
            **kwargs,
        )

    def ListFiles(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.workspace.Workspace/ListFiles",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.workspace.ListFilesOutput"),
            **kwargs,
        )

    def DescribeFile(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.workspace.Workspace/DescribeFile",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.workspace.DescribeFileOutput"),
            **kwargs,
        )

    def UploadFile(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.workspace.Workspace/UploadFile",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.workspace.UploadFileOutput"),
            **kwargs,
        )

    def RemoveFile(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.workspace.Workspace/RemoveFile",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.workspace.RemoveFileOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/access_key.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/cognito/access_key.proto\x12\x0e\x65olymp.cognito\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x01\n\tAccessKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05scope\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB7Z5github.com/eolymp/contracts/go/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.access_key_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/contracts/go/eolymp/cognito;cognito'
  _ACCESSKEY._serialized_start=85
  _ACCESSKEY._serialized_end=233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/scoreboard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/judge/scoreboard.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x06\n\nScoreboard\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x04 \x01(\x08\x12\x0f\n\x07visible\x18\x05 \x01(\x08\x12\x17\n\x0f\x61ttempt_penalty\x18\x1e \x01(\r\x12/\n\x06status\x18\x0b \x01(\x0e\x32\x1f.eolymp.judge.Scoreboard.Status\x12/\n\x0b\x66reeze_time\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tfreeze_in\x18\x16 \x01(\r\x1a\xb7\x01\n\x03Row\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05score\x18\n \x01(\x02\x12\x0f\n\x07penalty\x18\x0b \x01(\x02\x12\x0c\n\x04rank\x18\x0c \x01(\r\x12\x12\n\nrank_lower\x18\r \x01(\r\x12\x31\n\tbreakdown\x18\x14 \x03(\x0b\x32\x1e.eolymp.judge.Scoreboard.Score\x1a\xe8\x01\n\x05Score\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12\x0f\n\x07penalty\x18\x03 \x01(\x02\x12\x0e\n\x06solved\x18\x04 \x01(\x08\x12\x12\n\npercentage\x18\x05 \x01(\x02\x12\x10\n\x08\x61ttempts\x18\x07 \x01(\r\x12-\n\tsolved_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tsolved_in\x18\t \x01(\r\x12\x33\n\tbreakdown\x18\x14 \x03(\x0b\x32 .eolymp.judge.Scoreboard.Testset\x1aI\n\x07Testset\x12\x12\n\ntestset_id\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\x0c\n\x04\x63ost\x18\n \x01(\x02\x12\r\n\x05score\x18\x0b \x01(\x02\"I\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\n\n\x06\x46ROZEN\x10\x02\x12\x0e\n\nREBUILDING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.scoreboard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge'
  _SCOREBOARD._serialized_start=81
  _SCOREBOARD._serialized_end=886
  _SCOREBOARD_ROW._serialized_start=318
  _SCOREBOARD_ROW._serialized_end=501
  _SCOREBOARD_SCORE._serialized_start=504
  _SCOREBOARD_SCORE._serialized_end=736
  _SCOREBOARD_TESTSET._serialized_start=738
  _SCOREBOARD_TESTSET._serialized_end=811
  _SCOREBOARD_STATUS._serialized_start=813
  _SCOREBOARD_STATUS._serialized_end=886
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Project(_message.Message):
    __slots__ = ["atlas_problem_id", "author_id", "id", "labels", "name", "runtime", "visibility"]
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ATLAS_PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    AUTHOR_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRIVATE: Project.Visibility
    PUBLIC: Project.Visibility
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    atlas_problem_id: str
    author_id: str
    id: str
    labels: _containers.RepeatedScalarFieldContainer[str]
    name: str
    runtime: str
    visibility: Project.Visibility
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., runtime: _Optional[str] = ..., visibility: _Optional[_Union[Project.Visibility, str]] = ..., author_id: _Optional[str] = ..., atlas_problem_id: _Optional[str] = ..., labels: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class HelpdeskClient:
    def __init__(self, transport):
        self.transport = transport

    def DescribeDocument(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.helpdesk.Helpdesk/DescribeDocument",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.helpdesk.DescribeDocumentOutput"),
            **kwargs,
        )

    def ListDocuments(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.helpdesk.Helpdesk/ListDocuments",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.helpdesk.ListDocumentsOutput"),
            **kwargs,
        )

    def CreateDocument(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.helpdesk.Helpdesk/CreateDocument",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.helpdesk.CreateDocumentOutput"),
            **kwargs,
        )

    def UpdateDocument(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.helpdesk.Helpdesk/UpdateDocument",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.helpdesk.UpdateDocumentOutput"),
            **kwargs,
        )

    def DeleteDocument(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.helpdesk.Helpdesk/DeleteDocument",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.helpdesk.DeleteDocumentOutput"),
            **kwargs,
        )

    def DescribePath(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.helpdesk.Helpdesk/DescribePath",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.helpdesk.DescribePathOutput"),
            **kwargs,
        )

    def ListPaths(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.helpdesk.Helpdesk/ListPaths",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.helpdesk.ListPathsOutput"),
            **kwargs,
        )

    def ListParents(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.helpdesk.Helpdesk/ListParents",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.helpdesk.ListParentsOutput"),
            **kwargs,
        )




from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Scoreboard(_message.Message):
    __slots__ = ["attempt_penalty", "contest_id", "default", "freeze_in", "freeze_time", "id", "name", "status", "visible"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Row(_message.Message):
        __slots__ = ["breakdown", "name", "participant_id", "penalty", "rank", "rank_lower", "score", "scoreboard_id"]
        BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
        PENALTY_FIELD_NUMBER: _ClassVar[int]
        RANK_FIELD_NUMBER: _ClassVar[int]
        RANK_LOWER_FIELD_NUMBER: _ClassVar[int]
        SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        breakdown: _containers.RepeatedCompositeFieldContainer[Scoreboard.Score]
        name: str
        participant_id: str
        penalty: float
        rank: int
        rank_lower: int
        score: float
        scoreboard_id: str
        def __init__(self, participant_id: _Optional[str] = ..., scoreboard_id: _Optional[str] = ..., name: _Optional[str] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., rank: _Optional[int] = ..., rank_lower: _Optional[int] = ..., breakdown: _Optional[_Iterable[_Union[Scoreboard.Score, _Mapping]]] = ...) -> None: ...
    class Score(_message.Message):
        __slots__ = ["attempts", "breakdown", "penalty", "percentage", "problem_id", "score", "solved", "solved_at", "solved_in"]
        ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
        BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
        PENALTY_FIELD_NUMBER: _ClassVar[int]
        PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
        PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        SOLVED_AT_FIELD_NUMBER: _ClassVar[int]
        SOLVED_FIELD_NUMBER: _ClassVar[int]
        SOLVED_IN_FIELD_NUMBER: _ClassVar[int]
        attempts: int
        breakdown: _containers.RepeatedCompositeFieldContainer[Scoreboard.Testset]
        penalty: float
        percentage: float
        problem_id: str
        score: float
        solved: bool
        solved_at: _timestamp_pb2.Timestamp
        solved_in: int
        def __init__(self, problem_id: _Optional[str] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., solved: bool = ..., percentage: _Optional[float] = ..., attempts: _Optional[int] = ..., solved_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., solved_in: _Optional[int] = ..., breakdown: _Optional[_Iterable[_Union[Scoreboard.Testset, _Mapping]]] = ...) -> None: ...
    class Testset(_message.Message):
        __slots__ = ["cost", "index", "score", "testset_id"]
        COST_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
        cost: float
        index: int
        score: float
        testset_id: str
        def __init__(self, testset_id: _Optional[str] = ..., index: _Optional[int] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ...) -> None: ...
    ACTIVE: Scoreboard.Status
    ATTEMPT_PENALTY_FIELD_NUMBER: _ClassVar[int]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FIELD_NUMBER: _ClassVar[int]
    FAILED: Scoreboard.Status
    FREEZE_IN_FIELD_NUMBER: _ClassVar[int]
    FREEZE_TIME_FIELD_NUMBER: _ClassVar[int]
    FROZEN: Scoreboard.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    REBUILDING: Scoreboard.Status
    STATUS_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN: Scoreboard.Status
    VISIBLE_FIELD_NUMBER: _ClassVar[int]
    attempt_penalty: int
    contest_id: str
    default: bool
    freeze_in: int
    freeze_time: _timestamp_pb2.Timestamp
    id: str
    name: str
    status: Scoreboard.Status
    visible: bool
    def __init__(self, id: _Optional[str] = ..., contest_id: _Optional[str] = ..., name: _Optional[str] = ..., default: bool = ..., visible: bool = ..., attempt_penalty: _Optional[int] = ..., status: _Optional[_Union[Scoreboard.Status, str]] = ..., freeze_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., freeze_in: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Template(_message.Message):
    __slots__ = ["footer", "header", "id", "problem_id", "runtime", "source"]
    FOOTER_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    footer: str
    header: str
    id: str
    problem_id: str
    runtime: str
    source: str
    def __init__(self, id: _Optional[str] = ..., problem_id: _Optional[str] = ..., runtime: _Optional[str] = ..., source: _Optional[str] = ..., header: _Optional[str] = ..., footer: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/workspace/workspace.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.workspace import file_pb2 as eolymp_dot_workspace_dot_file__pb2
from eolymp.workspace import project_pb2 as eolymp_dot_workspace_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/workspace/workspace.proto\x12\x10\x65olymp.workspace\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1b\x65olymp/workspace/file.proto\x1a\x1e\x65olymp/workspace/project.proto\"*\n\x14\x44\x65scribeProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\"C\n\x15\x44\x65scribeProjectOutput\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\"1\n\x11ListProjectsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"M\n\x12ListProjectsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.workspace.Project\"@\n\x12\x43reateProjectInput\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\")\n\x13\x43reateProjectOutput\x12\x12\n\nproject_id\x18\x01 \x01(\t\"T\n\x12UpdateProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12*\n\x07project\x18\x02 \x01(\x0b\x32\x19.eolymp.workspace.Project\"\x15\n\x13UpdateProjectOutput\"(\n\x12\x44\x65leteProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProjectOutput\"B\n\x0eListFilesInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"G\n\x0fListFilesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.workspace.File\"5\n\x11\x44\x65scribeFileInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x12\x44\x65scribeFileOutput\x12$\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x16.eolymp.workspace.File\"D\n\x0fUploadFileInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"\x12\n\x10UploadFileOutput\"3\n\x0fRemoveFileInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x12\n\x10RemoveFileOutput2\x85\r\n\tWorkspace\x12\xc2\x01\n\x0f\x44\x65scribeProject\x12&.eolymp.workspace.DescribeProjectInput\x1a\'.eolymp.workspace.DescribeProjectOutput\"^\x82\xe3\n\x1a\x8a\xe3\n\x16workspace:project:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02*\x12\x1f/workspace/project/{project_id}:\x07project\x12\xa4\x01\n\x0cListProjects\x12#.eolymp.workspace.ListProjectsInput\x1a$.eolymp.workspace.ListProjectsOutput\"I\x82\xe3\n\x1a\x8a\xe3\n\x16workspace:project:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x12\x14/workspace/projects/\x12\xa9\x01\n\rCreateProject\x12$.eolymp.workspace.CreateProjectInput\x1a%.eolymp.workspace.CreateProjectOutput\"K\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x17\"\x12/workspace/project:\x01*\x12\xb6\x01\n\rUpdateProject\x12$.eolymp.workspace.UpdateProjectInput\x1a%.eolymp.workspace.UpdateProjectOutput\"X\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02$\x1a\x1f/workspace/project/{project_id}:\x01*\x12\xb6\x01\n\rDeleteProject\x12$.eolymp.workspace.DeleteProjectInput\x1a%.eolymp.workspace.DeleteProjectOutput\"X\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02$*\x1f/workspace/project/{project_id}:\x01*\x12\xad\x01\n\tListFiles\x12 .eolymp.workspace.ListFilesInput\x1a!.eolymp.workspace.ListFilesOutput\"[\x82\xe3\n\x1a\x8a\xe3\n\x16workspace:project:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02(\x12&/workspace/projects/{project_id}/files\x12\xc1\x01\n\x0c\x44\x65scribeFile\x12#.eolymp.workspace.DescribeFileInput\x1a$.eolymp.workspace.DescribeFileOutput\"f\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x32\x12-/workspace/projects/{project_id}/files/{name}:\x01*\x12\xbb\x01\n\nUploadFile\x12!.eolymp.workspace.UploadFileInput\x1a\".eolymp.workspace.UploadFileOutput\"f\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x32\x1a-/workspace/projects/{project_id}/files/{name}:\x01*\x12\xbb\x01\n\nRemoveFile\x12!.eolymp.workspace.RemoveFileInput\x1a\".eolymp.workspace.RemoveFileOutput\"f\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x32*-/workspace/projects/{project_id}/files/{name}:\x01*B;Z9github.com/eolymp/contracts/go/eolymp/workspace;workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.workspace.workspace_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/eolymp/contracts/go/eolymp/workspace;workspace'
  _WORKSPACE.methods_by_name['DescribeProject']._options = None
  _WORKSPACE.methods_by_name['DescribeProject']._serialized_options = b'\202\343\n\032\212\343\n\026workspace:project:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002*\022\037/workspace/project/{project_id}:\007project'
  _WORKSPACE.methods_by_name['ListProjects']._options = None
  _WORKSPACE.methods_by_name['ListProjects']._serialized_options = b'\202\343\n\032\212\343\n\026workspace:project:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\026\022\024/workspace/projects/'
  _WORKSPACE.methods_by_name['CreateProject']._options = None
  _WORKSPACE.methods_by_name['CreateProject']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\027\"\022/workspace/project:\001*'
  _WORKSPACE.methods_by_name['UpdateProject']._options = None
  _WORKSPACE.methods_by_name['UpdateProject']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002$\032\037/workspace/project/{project_id}:\001*'
  _WORKSPACE.methods_by_name['DeleteProject']._options = None
  _WORKSPACE.methods_by_name['DeleteProject']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002$*\037/workspace/project/{project_id}:\001*'
  _WORKSPACE.methods_by_name['ListFiles']._options = None
  _WORKSPACE.methods_by_name['ListFiles']._serialized_options = b'\202\343\n\032\212\343\n\026workspace:project:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002(\022&/workspace/projects/{project_id}/files'
  _WORKSPACE.methods_by_name['DescribeFile']._options = None
  _WORKSPACE.methods_by_name['DescribeFile']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\0022\022-/workspace/projects/{project_id}/files/{name}:\001*'
  _WORKSPACE.methods_by_name['UploadFile']._options = None
  _WORKSPACE.methods_by_name['UploadFile']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\0022\032-/workspace/projects/{project_id}/files/{name}:\001*'
  _WORKSPACE.methods_by_name['RemoveFile']._options = None
  _WORKSPACE.methods_by_name['RemoveFile']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\0022*-/workspace/projects/{project_id}/files/{name}:\001*'
  _DESCRIBEPROJECTINPUT._serialized_start=214
  _DESCRIBEPROJECTINPUT._serialized_end=256
  _DESCRIBEPROJECTOUTPUT._serialized_start=258
  _DESCRIBEPROJECTOUTPUT._serialized_end=325
  _LISTPROJECTSINPUT._serialized_start=327
  _LISTPROJECTSINPUT._serialized_end=376
  _LISTPROJECTSOUTPUT._serialized_start=378
  _LISTPROJECTSOUTPUT._serialized_end=455
  _CREATEPROJECTINPUT._serialized_start=457
  _CREATEPROJECTINPUT._serialized_end=521
  _CREATEPROJECTOUTPUT._serialized_start=523
  _CREATEPROJECTOUTPUT._serialized_end=564
  _UPDATEPROJECTINPUT._serialized_start=566
  _UPDATEPROJECTINPUT._serialized_end=650
  _UPDATEPROJECTOUTPUT._serialized_start=652
  _UPDATEPROJECTOUTPUT._serialized_end=673
  _DELETEPROJECTINPUT._serialized_start=675
  _DELETEPROJECTINPUT._serialized_end=715
  _DELETEPROJECTOUTPUT._serialized_start=717
  _DELETEPROJECTOUTPUT._serialized_end=738
  _LISTFILESINPUT._serialized_start=740
  _LISTFILESINPUT._serialized_end=806
  _LISTFILESOUTPUT._serialized_start=808
  _LISTFILESOUTPUT._serialized_end=879
  _DESCRIBEFILEINPUT._serialized_start=881
  _DESCRIBEFILEINPUT._serialized_end=934
  _DESCRIBEFILEOUTPUT._serialized_start=936
  _DESCRIBEFILEOUTPUT._serialized_end=994
  _UPLOADFILEINPUT._serialized_start=996
  _UPLOADFILEINPUT._serialized_end=1064
  _UPLOADFILEOUTPUT._serialized_start=1066
  _UPLOADFILEOUTPUT._serialized_end=1084
  _REMOVEFILEINPUT._serialized_start=1086
  _REMOVEFILEINPUT._serialized_end=1137
  _REMOVEFILEOUTPUT._serialized_start=1139
  _REMOVEFILEOUTPUT._serialized_end=1157
  _WORKSPACE._serialized_start=1160
  _WORKSPACE._serialized_end=2829
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/scoring.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/atlas/scoring.proto\x12\x0c\x65olymp.atlas*.\n\x0bScoringMode\x12\x0c\n\x08NO_SCORE\x10\x00\x12\x08\n\x04\x45\x41\x43H\x10\x01\x12\x07\n\x03\x41LL\x10\x02\x42\x33Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.scoring_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas'
  _SCORINGMODE._serialized_start=44
  _SCORINGMODE._serialized_end=90
# @@protoc_insertion_point(module_scope)
